ItsDangerous signed token implementation.
This namespace provides two main signatures: sign and verify,
refer to their documentation for details. ItsDangerous uses a simple
HMAC-based scheme to sign credentials. It is widely used in the Python
world, especially in Flask applications.
See https://itsdangerous.palletsprojects.com/ for more details.
ItsDangerous signed token implementation. This namespace provides two main signatures: `sign` and `verify`, refer to their documentation for details. ItsDangerous uses a simple HMAC-based scheme to sign credentials. It is widely used in the Python world, especially in Flask applications. See https://itsdangerous.palletsprojects.com/ for more details.
Default maximum token size in bytes (1 MB).
Default maximum token size in bytes (1 MB).
(digest= d1 d2)Tolerate some seconds of clock skew between emitter and verifier
Tolerate some seconds of clock skew between emitter and verifier
(sign input-config)(sign config payload)(sign config payload timestamp)Run the signature process for a payload, yields token as a string.
Needs at least ::algorithm, ::salt, ::sign-key, and ::payload.
::algorithm, ::salt, and ::sign-key are shared knowledge elements.
::signer-type controls the token format:
::signer (untimed, raw payload)::timestamp-signer (timed, raw payload) — default::url-safe-serializer (untimed, JSON payload, optional zlib compression)::url-safe-timed-serializer (timed, JSON payload, optional zlib compression)::key-derivation defaults to ::django-concat.
::timestamp defaults to the UNIX epoch in seconds.
Run the signature process for a payload, yields token as a string. Needs at least `::algorithm`, `::salt`, `::sign-key`, and `::payload`. `::algorithm`, `::salt`, and `::sign-key` are shared knowledge elements. `::signer-type` controls the token format: - `::signer` (untimed, raw payload) - `::timestamp-signer` (timed, raw payload) — default - `::url-safe-serializer` (untimed, JSON payload, optional zlib compression) - `::url-safe-timed-serializer` (timed, JSON payload, optional zlib compression) `::key-derivation` defaults to `::django-concat`. `::timestamp` defaults to the UNIX epoch in seconds.
(verify input-config)(verify config token)(verify config token max-age)Run verification on a token, throwing if the signature is invalid or if the token's validity has expired. Yields the payload upon success.
Needs at least ::algorithm, ::salt, ::verify-keys, and ::token.
::signer-type defaults to ::timestamp-signer.
::key-derivation defaults to ::django-concat.
Optionally accepts ::max-age, in which case token validity in time will be
checked. Tokens whose timestamp is more than 60 seconds in the future are
rejected as well, to tolerate clock skew between emitter and verifier.
::max-size controls the maximum token size in bytes (default 1MB). It
also bounds the decompressed payload size for URL-safe serializer types.
Run verification on a token, throwing if the signature is invalid or if the token's validity has expired. Yields the payload upon success. Needs at least `::algorithm`, `::salt`, `::verify-keys`, and `::token`. `::signer-type` defaults to `::timestamp-signer`. `::key-derivation` defaults to `::django-concat`. Optionally accepts `::max-age`, in which case token validity in time will be checked. Tokens whose timestamp is more than 60 seconds in the future are rejected as well, to tolerate clock skew between emitter and verifier. `::max-size` controls the maximum token size in bytes (default 1MB). It also bounds the decompressed payload size for URL-safe serializer types.
cljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |