exoscale.itsdangerous.hmac

JavaSE based implementation of hashed based message authentication.

JavaSE based implementation of hashed based message
authentication.
raw docstring

derive-keyclj

(derive-key algorithm key-derivation secret salt)

Derive a key from secret and salt using the given algorithm and key derivation method.

Supported methods:

  • :hmac — HMAC(secret, salt)
  • :concat — hash(salt + secret)
  • :django-concat — hash(salt + 'signer' + secret)
Derive a key from secret and salt using the given algorithm and key derivation method.

Supported methods:
- :hmac          — HMAC(secret, salt)
- :concat        — hash(salt + secret)
- :django-concat — hash(salt + 'signer' + secret)
raw docstring

digestclj

(digest algorithm data)

Compute the hash of a byte array using the given algorithm.

Compute the hash of a byte array using the given algorithm.
raw docstring

hash-algorithm-nameclj

(hash-algorithm-name algorithm)

Get the hash algorithm name (e.g. 'SHA-1') for a given algorithm keyword.

Get the hash algorithm name (e.g. 'SHA-1') for a given algorithm keyword.
raw docstring

hmac-algorithm-nameclj

(hmac-algorithm-name algorithm)

Get the HMAC algorithm name (e.g. 'HmacSHA1') for a given algorithm keyword.

Get the HMAC algorithm name (e.g. 'HmacSHA1') for a given algorithm keyword.
raw docstring

hmac-signclj

(hmac-sign algorithm raw-input derived-key)

Compute the HMAC of a payload using the given algorithm and key.

Compute the HMAC of a payload using the given algorithm and key.
raw docstring

cljdoc builds & hosts documentation for Clojure/Script libraries