JavaSE based implementation of hashed based message authentication.
JavaSE based implementation of hashed based message authentication.
(derive-key algorithm key-derivation secret salt)Derive a key from secret and salt using the given algorithm and key derivation method.
Supported methods:
Derive a key from secret and salt using the given algorithm and key derivation method. Supported methods: - :hmac — HMAC(secret, salt) - :concat — hash(salt + secret) - :django-concat — hash(salt + 'signer' + secret)
(digest algorithm data)Compute the hash of a byte array using the given algorithm.
Compute the hash of a byte array using the given algorithm.
(hash-algorithm-name algorithm)Get the hash algorithm name (e.g. 'SHA-1') for a given algorithm keyword.
Get the hash algorithm name (e.g. 'SHA-1') for a given algorithm keyword.
(hmac-algorithm-name algorithm)Get the HMAC algorithm name (e.g. 'HmacSHA1') for a given algorithm keyword.
Get the HMAC algorithm name (e.g. 'HmacSHA1') for a given algorithm keyword.
(hmac-sign algorithm raw-input derived-key)Compute the HMAC of a payload using the given algorithm and key.
Compute the HMAC of a payload using the given algorithm and key.
cljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |